@@ -2,7 +2,7 @@
 import urllib.parse as urlparse
 from typing import Any, Callable, Dict, Iterable, List, Optional, Union
 
-from pydantic import BaseModel, PrivateAttr
+from pydantic import BaseModel, Field, PrivateAttr
 
 from redbird.oper import GreaterEqual, GreaterThan, LessEqual, LessThan, NotEqual, Operation
 from redbird.base import BaseResult, BaseRepo
@@ -32,6 +32,12 @@ class RESTRepo(TemplateRepo):
 
     Parameters
     ----------
+    url : str
+        Base URL for the API. Should not contain
+        query parameters or the item ID. The full
+        URL will be "{url}/{id}" if a single item
+        is searched, "{url}?{param}={value}" if 
+        the endpoint is queried.
     model : Type
         Class of an item in the repository.
         Commonly dict or subclass of Pydantic
@@ -49,13 +55,7 @@ class RESTRepo(TemplateRepo):
         Whether to raise an exception, warn or discard
         the item in case of validation error in 
         converting data to the item model from
-        the repository. By default raise 
-    url : str
-        Base URL for the API. Should not contain
-        query parameters or the item ID. The full
-        URL will be "{url}/{id}" if a single item
-        is searched, "{url}?{param}={value}" if 
-        the endpoint is queried.
+        the repository. By default raise
     headers : dict
         HTTP Headers (for example authentication)
     url_params : dict
@@ -75,13 +75,13 @@ class RESTRepo(TemplateRepo):
     .. code-block:: python
 
         token = "1234567890"
-        repo = MemoryRepo(url="http://example.com/api", headers={"Authorization": f"Bearer {token}"})
+        repo = RESTRepo(url="http://example.com/api", headers={"Authorization": f"Bearer {token}"})
 
     You may also supply some URL parameters for every query:
 
     .. code-block:: python
 
-        repo = MemoryRepo(url="http://example.com/api", url_params={"fields": "car_type,car_model,registration_number"})
+        repo = RESTRepo(url="http://example.com/api", url_params={"fields": "car_type,car_model,registration_number"})
     """
     result: Optional[Union[str, Callable]]
     url: str
@@ -90,6 +90,8 @@ class RESTRepo(TemplateRepo):
 
     _session = PrivateAttr()
 
+    ordered: bool = Field(default=False, const=True)
+
     def insert(self, item):
         json = self.item_to_dict(item)
         self._request(
@@ -109,7 +111,7 @@ class RESTRepo(TemplateRepo):
         )
         return page
 
-    def query_read(self, query):
+    def query_data(self, query):
         url = query
         page = self._request("GET", url)
         output = page.json()
