@@ -14,7 +14,7 @@ from redbird.repos.rest import RESTRepo
 from redbird.repos.sqlalchemy import SQLRepo
 from redbird.repos.memory import MemoryRepo
 from redbird.repos.mongo import MongoRepo
-from redbird.oper import skip, between, greater_equal, greater_than, less_equal, less_than, not_equal
+from redbird.oper import in_, skip, between, greater_equal, greater_than, less_equal, less_than, not_equal
 
 from pydantic import BaseModel, Field
 
@@ -505,6 +505,25 @@ class TestFilteringOperations(RepoTests):
             expected = sort_items(expected, repo)
         assert actual == expected
 
+    def test_in(self, repo):
+        self.populate(repo)
+        if isinstance(repo, RESTRepo):
+            pytest.xfail("RESTRepo does not support operations (yet)")
+        Item = repo.model
+        actual = repo.filter_by(age=in_([20, 41])).all() 
+        expected = [
+            Item(id="a", name="Jack", age=20),
+            #Item(id="b", name="John", age=30),
+            #Item(id="c", name="James", age=30),
+            #Item(id="d", name="Johnny", age=30),
+            #Item(id="e", name="Jesse", age=40),
+            Item(id="f", name="Jim", age=41),
+        ]
+        if not repo.ordered:
+            actual = sort_items(actual, repo)
+            expected = sort_items(expected, repo)
+        assert actual == expected
+
     def test_skip(self, repo):
         self.populate(repo)
         if isinstance(repo, RESTRepo):
